@@ -8,6 +8,9 @@
 ##'
 ##' @param m rasterLayer, mean min temperature of the coldest month
 ##'
+##'	@param tempScale integer; scaling factor for the temperature data, see \link{envirem} for 
+##' 	additional details. 
+##'
 ##' @details \code{Q = 2000 P / [(M + m + 546.4) * (M - m)]}
 ##'
 ##' @return rasterLayer in mm / degrees C
@@ -23,7 +26,7 @@
 ##' rasterFiles <- list.files(system.file('extdata', package='envirem'), full.names=TRUE)
 ##' env <- stack(rasterFiles)
 ##'
-##' embergerQ(env[['bio_12']], env[['bio_5']], env[['bio_6']])
+##' embergerQ(env[['bio_12']], env[['bio_5']], env[['bio_6']], tempScale = 10)
 ##' @export
 
 
@@ -32,12 +35,11 @@
 # P = mean annual precip
 # M = mean max temp of warmest month
 # m = mean min temp of coldest month
-# assuming temp rasters are in degC * 10 (default in worldclim)
-embergerQ <- function(P, M, m) {
+embergerQ <- function(P, M, m, tempScale = 1) {
 	
 	#switch to 1 deg Celsius
-	raster::values(M) <- raster::values(M)/10
-	raster::values(m) <- raster::values(m)/10
+	raster::values(M) <- raster::values(M) / tempScale
+	raster::values(m) <- raster::values(m) / tempScale
 	res <- 2000 * P / ((M + m + 546.4) * (M - m))
 	names(res) <- 'embergerQ'
 	return(res)
